[suite filter_cmd]
caption = filters
[subcommand aacdec]
	purpose = decode an aac stream
[subcommand amp]
	purpose = amplify (scale) a raw audio stream
	[option amp]
		short_opt = a
		summary = amplification value
		typestr = number
		arg_info = required_arg
		arg_type = uint32
		default_val = 32
		[help]
			The amplification value determines the scaling factor by which the
			amplitude of the audio stream is multiplied. The formula for the
			scaling factor is

				factor = 1 + amp / 64.

			For example, an amplification value of zero results in a scaling factor
			of one while an amplification value of 64 means to double the volume.
		[/help]
[subcommand compress]
	purpose = dynamically adjust the volume of an audio stream
	[option blocksize]
		short_opt = b
		summary = use blocks of size 2**bits
		typestr = bits
		arg_info = required_arg
		arg_type = uint32
		default_val = 15
		[help]
			Larger blocksize means fewer volume adjustments per time unit.
		[/help]
	[option aggressiveness]
		short_opt = a
		summary = controls the maximum amount to amplify by
		typestr = bits
		arg_info = required_arg
		arg_type = uint32
		default_val = 4
	[option inertia]
		short_opt = i
		summary = how much inertia ramping has
		typestr = bits
		arg_info = required_arg
		arg_type = uint32
		default_val = 6
	[option target-level]
		short_opt = t
		summary = target signal level (0-32768)
		typestr = level
		arg_info = required_arg
		arg_type = uint32
		default_val = 20000
	[option damp]
		short_opt = d
		summary = if non-zero, scale down after normalizing
		typestr = bits
		arg_info = required_arg
		arg_type = uint32
		default_val = 0
[subcommand fecdec]
	purpose = decode a (lossy) input stream using forward error correction
[subcommand flacdec]
	purpose = decode a flac stream
[subcommand mp3dec]
	purpose = decode an mp3 stream
	[option ignore-crc]
		short_opt = i
		summary = ignore CRC information in the audio stream
		[help]
			This causes frames with CRC errors to be decoded and played
			anyway. This option is not recommended, but since some encoders
			have been known to generate bad CRC information, this option is a
			work-around to play streams from such encoders.
		[/help]
[subcommand oggdec]
	purpose = decode an ogg/vorbis stream
[subcommand opusdec]
	purpose = decode an ogg/opus stream
[subcommand prebuffer]
	purpose = delay processing of an audio stream
	[option duration]
		short_opt = d
		summary = length of the prebuffer period
		typestr = milliseconds
		arg_info = required_arg
		arg_type = uint32
		default_val = 200
		[help]
			Wait this many milliseconds before letting data go through. The time
			interval starts when the first data byte is seen in the input queue.
		[/help]
	[option size]
		short_opt = s
		summary = amount of data to prebuffer
		typestr = bytes
		arg_info = required_arg
		arg_type = uint32
		default_val = 0
		[help]
			Wait until this many data bytes are available in the input queue. The
			default value of zero means to not prebuffer by size. If both
			--duration and --size are given and non-zero, the prebuffer filter
			waits until both conditions are met.
		[/help]
[subcommand resample]
	purpose = transform raw audio to a different sample rate
	[option converter]
		short_opt = C
		summary = set conversion algorithm
		typestr = type
		arg_info = required_arg
		arg_type = string
		values = {
			# RCT: resample conversion type
			RCT_BEST = "best",
			RCT_MEDIUM = "medium",
			RCT_FASTEST = "fastest",
			RCT_ZERO_ORDER_HOLD = "zero_order_hold",
			RCT_LINEAR = "linear"
		}
		default_val = medium
		[help]
			best: This is a bandlimited interpolator derived from the mathematical
			sinc function and this is the highest quality sinc based converter,
			providing a worst case Signal-to-Noise Ratio (SNR) of 97 decibels
			(dB) at a bandwidth of 97%.

			medium: This is another bandlimited interpolator much like the previous
			one. It has an SNR of 97dB and a bandwidth of 90%. The speed of the
			conversion is much faster than the previous one.

			fastest: This is the fastest bandlimited interpolator and has an SNR
			of 97dB and a bandwidth of 80%.

			zero_order_hold: A Zero Order Hold converter (interpolated value
			is equal to the last value). The quality is poor but the conversion
			speed is blindlingly fast.

			linear: A linear converter. Again the quality is poor, but the
			conversion speed is blindingly fast.
		[/help]
	[option dest-sample-rate]
		short_opt = d
		summary = sample rate to convert to
		typestr = rate
		arg_info = required_arg
		arg_type = uint32
		default_val = 44100
	m4_include(channels.m4)
	m4_include(sample-rate.m4)
	m4_include(sample-format.m4)
[subcommand spxdec]
	purpose = decode an ogg/speex stream
[subcommand sync]
	purpose = synchronize playback between multiple clients
	[option buddy]
		short_opt = b
		summary = client to synchronize with
		typestr = url
		arg_info = required_arg
		arg_type = string
		flag multiple
		[help]
			This option may be given multiple times, one per buddy. Each value
			may be given as a host, port pair in either IPv4 or IPv6 form, with
			port being optional. If no port was specified the listening port (as
			specified with --port, see below) is used to send the synchronization
			packet to this buddy.
		[/help]
	[option port]
		short_opt = p
		summary = UDP port for incoming synchronization packets
		typestr = portnumber
		arg_info = required_arg
		arg_type = uint32
		default_val = 29900
		[help]
			The sync filter expects incoming synchronization packets on this
			UDP port.
		[/help]
	[option timeout]
		short_opt = t
		summary = how long to wait for other clients
		typestr = milliseconds
		arg_info = required_arg
		arg_type = uint32
		default_val = 2000
		[help]
			Once the sync filter receives its first chunk of input,
			a synchronization period of the given number of milliseconds
			begins. Playback is deferred until a synchronization packet has
			been received from each defined buddy, or until the end of the
			period. Buddies which did not send a synchronization packet in time
			are temporarily disabled and are not waited for during subsequent
			synchronization periods. They are re-enabled automatically when
			another synchronization packet arrives.
		[/help]
[subcommand wav]
	purpose = insert a Microsoft wave header into a raw audio stream
[subcommand wmadec]
	purpose = decode a wma stream
